# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.secret_service import secret_service_pb2 as qwak_dot_secret__service_dot_secret__service__pb2


class SecretServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/SetSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.FromString,
                )
        self.GetSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/GetSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.FromString,
                )
        self.DeleteSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/DeleteSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.FromString,
                )


class SecretServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetSecret(self, request, context):
        """Set a value for a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Get a secret value
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSecret(self, request, context):
        """Remove a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.SerializeToString,
            ),
            'DeleteSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.secret.service.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/SetSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/GetSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/DeleteSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.features.deployment_pb2
import qwak.feature_store.features.execution_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PythonVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PythonVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PythonVersion.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PYTHON_VERSION_INVALID: _PythonVersion.ValueType  # 0
    PYTHON_VERSION_3_7: _PythonVersion.ValueType  # 1
    PYTHON_VERSION_3_8: _PythonVersion.ValueType  # 2
    PYTHON_VERSION_3_9: _PythonVersion.ValueType  # 3

class PythonVersion(_PythonVersion, metaclass=_PythonVersionEnumTypeWrapper): ...

PYTHON_VERSION_INVALID: PythonVersion.ValueType  # 0
PYTHON_VERSION_3_7: PythonVersion.ValueType  # 1
PYTHON_VERSION_3_8: PythonVersion.ValueType  # 2
PYTHON_VERSION_3_9: PythonVersion.ValueType  # 3
global___PythonVersion = PythonVersion

class RealTimeFeatureExtractor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REAL_TIME_FEATURE_EXTRACTOR_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def real_time_feature_extractor_definition(self) -> global___RealTimeFeatureExtractorDefinition:
        """Definition of the real time extractor"""
    @property
    def metadata(self) -> global___RealTimeFeatureExtractorMetadata:
        """Metadata of the real time extractor"""
    def __init__(
        self,
        *,
        real_time_feature_extractor_definition: global___RealTimeFeatureExtractorDefinition | None = ...,
        metadata: global___RealTimeFeatureExtractorMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "real_time_feature_extractor_definition", b"real_time_feature_extractor_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "real_time_feature_extractor_definition", b"real_time_feature_extractor_definition"]) -> None: ...

global___RealTimeFeatureExtractor = RealTimeFeatureExtractor

class RealTimeFeatureExtractorDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REAL_TIME_FEATURE_EXTRACTOR_ID_FIELD_NUMBER: builtins.int
    REAL_TIME_FEATURE_EXTRACTOR_SPEC_FIELD_NUMBER: builtins.int
    LAST_DEPLOYMENT_STATUS_FIELD_NUMBER: builtins.int
    real_time_feature_extractor_id: builtins.str
    """Assigned unique id of the real time extractor"""
    @property
    def real_time_feature_extractor_spec(self) -> global___RealTimeFeatureExtractorSpec:
        """Specifications of the real time extractor"""
    last_deployment_status: qwak.feature_store.features.deployment_pb2.DeploymentStatus.ValueType
    """Last deployment status of the real time extractor"""
    def __init__(
        self,
        *,
        real_time_feature_extractor_id: builtins.str = ...,
        real_time_feature_extractor_spec: global___RealTimeFeatureExtractorSpec | None = ...,
        last_deployment_status: qwak.feature_store.features.deployment_pb2.DeploymentStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["real_time_feature_extractor_spec", b"real_time_feature_extractor_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_deployment_status", b"last_deployment_status", "real_time_feature_extractor_id", b"real_time_feature_extractor_id", "real_time_feature_extractor_spec", b"real_time_feature_extractor_spec"]) -> None: ...

global___RealTimeFeatureExtractorDefinition = RealTimeFeatureExtractorDefinition

class RealTimeFeatureExtractorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFICATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the realtime feature extractor was created"""
    created_by: builtins.str
    """User that created the real time extractor"""
    @property
    def last_modification_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When was the real time extractor last modified"""
    last_modified_by: builtins.str
    """User that last modified the real time extractor"""
    def __init__(
        self,
        *,
        created_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        last_modification_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "last_modification_timestamp", b"last_modification_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_by", b"created_by", "created_timestamp", b"created_timestamp", "last_modification_timestamp", b"last_modification_timestamp", "last_modified_by", b"last_modified_by"]) -> None: ...

global___RealTimeFeatureExtractorMetadata = RealTimeFeatureExtractorMetadata

class RealTimeFeatureExtractorSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REAL_TIME_ARTIFACT_FIELD_NUMBER: builtins.int
    DEPENDENCY_MANAGER_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    MAX_STALENESS_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def real_time_artifact(self) -> global___ExtractionArtifact:
        """Extraction artifact field containing all relevant information related to the code's artifact"""
    @property
    def dependency_manager(self) -> global___PythonDependencyManager:
        """Python dependency manager"""
    @property
    def client_pod_compute_resources(self) -> global___ExtractorComputeResources:
        """Resources dedicated to the real time extractor"""
    max_staleness_seconds: builtins.int
    """Max staleness time interval passed in seconds"""
    def __init__(
        self,
        *,
        real_time_artifact: global___ExtractionArtifact | None = ...,
        dependency_manager: global___PythonDependencyManager | None = ...,
        client_pod_compute_resources: global___ExtractorComputeResources | None = ...,
        max_staleness_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "dependency_manager", b"dependency_manager", "real_time_artifact", b"real_time_artifact"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "dependency_manager", b"dependency_manager", "max_staleness_seconds", b"max_staleness_seconds", "real_time_artifact", b"real_time_artifact"]) -> None: ...

global___RealTimeFeatureExtractorSpec = RealTimeFeatureExtractorSpec

class ExtractionArtifact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_S3_FIELD_NUMBER: builtins.int
    @property
    def aws_s3(self) -> global___AwsS3:
        """AWS S3 filesystem"""
    def __init__(
        self,
        *,
        aws_s3: global___AwsS3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_s3", b"aws_s3", "fs_type", b"fs_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_s3", b"aws_s3", "fs_type", b"fs_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["fs_type", b"fs_type"]) -> typing_extensions.Literal["aws_s3"] | None: ...

global___ExtractionArtifact = ExtractionArtifact

class AwsS3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_PATH_FIELD_NUMBER: builtins.int
    artifact_path: builtins.str
    """Path where the artifact can be found and downloaded from"""
    def __init__(
        self,
        *,
        artifact_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_path", b"artifact_path"]) -> None: ...

global___AwsS3 = AwsS3

class PythonDependencyManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    VIRTUALENV_FIELD_NUMBER: builtins.int
    CONDA_FIELD_NUMBER: builtins.int
    POETRY_FIELD_NUMBER: builtins.int
    python_version: global___PythonVersion.ValueType
    """Python version used"""
    @property
    def virtualenv(self) -> global___VirtualEnvironment:
        """virtualenv"""
    @property
    def conda(self) -> global___Conda:
        """conda"""
    @property
    def poetry(self) -> global___Poetry:
        """poetry"""
    def __init__(
        self,
        *,
        python_version: global___PythonVersion.ValueType = ...,
        virtualenv: global___VirtualEnvironment | None = ...,
        conda: global___Conda | None = ...,
        poetry: global___Poetry | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conda", b"conda", "poetry", b"poetry", "type", b"type", "virtualenv", b"virtualenv"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conda", b"conda", "poetry", b"poetry", "python_version", b"python_version", "type", b"type", "virtualenv", b"virtualenv"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["virtualenv", "conda", "poetry"] | None: ...

global___PythonDependencyManager = PythonDependencyManager

class Conda(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE64_ENCODED_CONDA_FILE_FIELD_NUMBER: builtins.int
    base64_encoded_conda_file: builtins.str
    """Base64 utf-8 encoded contents of a conda file"""
    def __init__(
        self,
        *,
        base64_encoded_conda_file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base64_encoded_conda_file", b"base64_encoded_conda_file"]) -> None: ...

global___Conda = Conda

class Poetry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE64_ENCODED_LOCK_FILE_FIELD_NUMBER: builtins.int
    base64_encoded_lock_file: builtins.str
    """Base64 utf-8 encoded contents of a poetry lock file"""
    def __init__(
        self,
        *,
        base64_encoded_lock_file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base64_encoded_lock_file", b"base64_encoded_lock_file"]) -> None: ...

global___Poetry = Poetry

class VirtualEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE64_ENCODED_REQUIREMENTS_TXT_FIELD_NUMBER: builtins.int
    base64_encoded_requirements_txt: builtins.str
    """Base64 utf-8 encoded contents of a requirements file,"""
    def __init__(
        self,
        *,
        base64_encoded_requirements_txt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base64_encoded_requirements_txt", b"base64_encoded_requirements_txt"]) -> None: ...

global___VirtualEnvironment = VirtualEnvironment

class ExtractorComputeResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_RESOURCE_TEMPLATE_FIELD_NUMBER: builtins.int
    PARALLELISM_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    compute_resource_template: qwak.feature_store.features.execution_pb2.ClusterTemplate.ValueType
    parallelism: builtins.int
    """Webserver workers"""
    replicas: builtins.int
    """Pod count"""
    def __init__(
        self,
        *,
        compute_resource_template: qwak.feature_store.features.execution_pb2.ClusterTemplate.ValueType = ...,
        parallelism: builtins.int = ...,
        replicas: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_resource_template", b"compute_resource_template", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_resource_template", b"compute_resource_template", "parallelism", b"parallelism", "replicas", b"replicas", "resources", b"resources"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["resources", b"resources"]) -> typing_extensions.Literal["compute_resource_template"] | None: ...

global___ExtractorComputeResources = ExtractorComputeResources

class RealtimeFeatureExtractorDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    EXTRACTOR_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CREATED_USER_ID_FIELD_NUMBER: builtins.int
    UPDATED_USER_ID_FIELD_NUMBER: builtins.int
    CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    UPDATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STATUS_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    extractor_id: builtins.str
    environment_id: builtins.str
    created_user_id: builtins.str
    updated_user_id: builtins.str
    @property
    def created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    deployment_status: qwak.feature_store.features.deployment_pb2.DeploymentStatus.ValueType
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        extractor_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        created_user_id: builtins.str = ...,
        updated_user_id: builtins.str = ...,
        created_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        deployment_status: qwak.feature_store.features.deployment_pb2.DeploymentStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "updated_timestamp", b"updated_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "created_user_id", b"created_user_id", "deployment_id", b"deployment_id", "deployment_status", b"deployment_status", "environment_id", b"environment_id", "extractor_id", b"extractor_id", "updated_timestamp", b"updated_timestamp", "updated_user_id", b"updated_user_id"]) -> None: ...

global___RealtimeFeatureExtractorDeployment = RealtimeFeatureExtractorDeployment

class RealtimeFeatureExtractorDeploymentUpdateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_REQUEST_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CREATED_USER_ID_FIELD_NUMBER: builtins.int
    REQUEST_STATE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    UPDATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    update_request_id: builtins.str
    deployment_id: builtins.str
    environment_id: builtins.str
    created_user_id: builtins.str
    @property
    def request_state(self) -> qwak.feature_store.features.deployment_pb2.DeploymentUpdateRequestState: ...
    deployment_failure_reason_code: qwak.feature_store.features.deployment_pb2.DeploymentFailureReasonCode.ValueType
    @property
    def created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        update_request_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        created_user_id: builtins.str = ...,
        request_state: qwak.feature_store.features.deployment_pb2.DeploymentUpdateRequestState | None = ...,
        deployment_failure_reason_code: qwak.feature_store.features.deployment_pb2.DeploymentFailureReasonCode.ValueType = ...,
        created_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "deployment_failure_reason_code", b"deployment_failure_reason_code", "failure_reason_code", b"failure_reason_code", "request_state", b"request_state", "updated_timestamp", b"updated_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "created_user_id", b"created_user_id", "deployment_failure_reason_code", b"deployment_failure_reason_code", "deployment_id", b"deployment_id", "environment_id", b"environment_id", "failure_reason_code", b"failure_reason_code", "request_state", b"request_state", "update_request_id", b"update_request_id", "updated_timestamp", b"updated_timestamp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["failure_reason_code", b"failure_reason_code"]) -> typing_extensions.Literal["deployment_failure_reason_code"] | None: ...

global___RealtimeFeatureExtractorDeploymentUpdateRequest = RealtimeFeatureExtractorDeploymentUpdateRequest



from functools import wraps
from typing import Any, Callable

from qwak.model.adapters import BaseInputAdapter, BaseOutputAdapter
from qwak.model.utils.extract_wrapped_function import extract_wrapped


def create_decorator_function(
    analytics: bool,
    feature_extraction: bool,
    input_adapter: BaseInputAdapter,
    output_adapter: BaseOutputAdapter,
    analytics_sample_ratio: float,
    analytics_exclude_columns: list,
) -> Callable:
    def api_decorator_function_load_logic(func: Callable[..., Any]):
        func = extract_wrapped(func)
        setattr(func, "_input_adapter", input_adapter)
        setattr(func, "_output_adapter", output_adapter)
        setattr(func, "_fs_extraction", feature_extraction)

        @wraps(func)
        def api_decorator_function_execution_logic(*args, **kwargs) -> Any:
            output = func(*args, **kwargs)
            return output

        return api_decorator_function_execution_logic

    return api_decorator_function_load_logic



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.workspace.workspace_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def workspace_spec(self) -> qwak.workspace.workspace_pb2.WorkspaceSpec:
        """Workspace spec"""
    def __init__(
        self,
        *,
        workspace_spec: qwak.workspace.workspace_pb2.WorkspaceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> None: ...

global___CreateWorkspaceRequest = CreateWorkspaceRequest

class CreateWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___CreateWorkspaceResponse = CreateWorkspaceResponse

class UpdateWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    WORKSPACE_SPEC_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def workspace_spec(self) -> qwak.workspace.workspace_pb2.WorkspaceSpec:
        """Workspace spec"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        workspace_spec: qwak.workspace.workspace_pb2.WorkspaceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id", "workspace_spec", b"workspace_spec"]) -> None: ...

global___UpdateWorkspaceRequest = UpdateWorkspaceRequest

class DeployWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___DeployWorkspaceRequest = DeployWorkspaceRequest

class DeployWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeployWorkspaceResponse = DeployWorkspaceResponse

class UndeployWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___UndeployWorkspaceRequest = UndeployWorkspaceRequest

class UndeployWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UndeployWorkspaceResponse = UndeployWorkspaceResponse

class UpdateWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateWorkspaceResponse = UpdateWorkspaceResponse

class ListWorkspacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListWorkspacesRequest = ListWorkspacesRequest

class ListWorkspacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACES_FIELD_NUMBER: builtins.int
    @property
    def workspaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.workspace.workspace_pb2.Workspace]:
        """List of workspaces"""
    def __init__(
        self,
        *,
        workspaces: collections.abc.Iterable[qwak.workspace.workspace_pb2.Workspace] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspaces", b"workspaces"]) -> None: ...

global___ListWorkspacesResponse = ListWorkspacesResponse

class GetWorkspaceByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___GetWorkspaceByIdRequest = GetWorkspaceByIdRequest

class GetWorkspaceByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_FIELD_NUMBER: builtins.int
    @property
    def workspace(self) -> qwak.workspace.workspace_pb2.Workspace:
        """Workspace details"""
    def __init__(
        self,
        *,
        workspace: qwak.workspace.workspace_pb2.Workspace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace", b"workspace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace", b"workspace"]) -> None: ...

global___GetWorkspaceByIdResponse = GetWorkspaceByIdResponse

class DeleteWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___DeleteWorkspaceRequest = DeleteWorkspaceRequest

class DeleteWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteWorkspaceResponse = DeleteWorkspaceResponse

class UpdateWorkspaceStatusFromEdgeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_WORKSPACE_STATUS_FROM_EDGE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def update_workspace_status_from_edge_details(self) -> qwak.workspace.workspace_pb2.UpdateWorkspaceStatusFromEdgeDetails: ...
    def __init__(
        self,
        *,
        update_workspace_status_from_edge_details: qwak.workspace.workspace_pb2.UpdateWorkspaceStatusFromEdgeDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["update_workspace_status_from_edge_details", b"update_workspace_status_from_edge_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["update_workspace_status_from_edge_details", b"update_workspace_status_from_edge_details"]) -> None: ...

global___UpdateWorkspaceStatusFromEdgeRequest = UpdateWorkspaceStatusFromEdgeRequest

class UpdateWorkspaceStatusFromEdgeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateWorkspaceStatusFromEdgeResponse = UpdateWorkspaceStatusFromEdgeResponse

class RegisterWorkspaceTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tag name"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tags", b"tags", "workspace_id", b"workspace_id"]) -> None: ...

global___RegisterWorkspaceTagRequest = RegisterWorkspaceTagRequest

class RegisterWorkspaceTagResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterWorkspaceTagResponse = RegisterWorkspaceTagResponse

class ListWorkspaceImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListWorkspaceImagesRequest = ListWorkspaceImagesRequest

class ListWorkspaceImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_IMAGES_FIELD_NUMBER: builtins.int
    @property
    def workspace_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.workspace.workspace_pb2.WorkspaceImage]:
        """List of workspace images"""
    def __init__(
        self,
        *,
        workspace_images: collections.abc.Iterable[qwak.workspace.workspace_pb2.WorkspaceImage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_images", b"workspace_images"]) -> None: ...

global___ListWorkspaceImagesResponse = ListWorkspaceImagesResponse

class CountWorkspacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CountWorkspacesRequest = CountWorkspacesRequest

class CountWorkspacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Count of workspaces"""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count"]) -> None: ...

global___CountWorkspacesResponse = CountWorkspacesResponse

class GetDefaultWorkspaceValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDefaultWorkspaceValuesRequest = GetDefaultWorkspaceValuesRequest

class GetDefaultWorkspaceValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_WORKSPACE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def default_workspace_details(self) -> qwak.workspace.workspace_pb2.DefaultWorkspaceDetails: ...
    def __init__(
        self,
        *,
        default_workspace_details: qwak.workspace.workspace_pb2.DefaultWorkspaceDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_workspace_details", b"default_workspace_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_workspace_details", b"default_workspace_details"]) -> None: ...

global___GetDefaultWorkspaceValuesResponse = GetDefaultWorkspaceValuesResponse

class MarkBuildAsCopiedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    build_id: builtins.str
    """Build id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "workspace_id", b"workspace_id"]) -> None: ...

global___MarkBuildAsCopiedRequest = MarkBuildAsCopiedRequest

class MarkBuildAsCopiedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MarkBuildAsCopiedResponse = MarkBuildAsCopiedResponse

class CopyBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    build_id: builtins.str
    """Build id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "workspace_id", b"workspace_id"]) -> None: ...

global___CopyBuildRequest = CopyBuildRequest

class CopyBuildResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CopyBuildResponse = CopyBuildResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.deployment.deployment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeployModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToDeploymentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentDeploymentMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentDeploymentMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    HOSTING_SERVICE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_DEPLOYMENT_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model named ID, which will be used as a routing key for the model"""
    branch_id: builtins.str
    """Branch ID to deploy the model under"""
    build_id: builtins.str
    """Build ID (which must be successful) to deploy"""
    @property
    def hosting_service(self) -> qwak.deployment.deployment_pb2.HostingService:
        """Downstream hosting service that will serve the Qwak model"""
    @property
    def environment_to_deployment(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentMessage]:
        """Environment ids to their deployment request mapping"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        hosting_service: qwak.deployment.deployment_pb2.HostingService | None = ...,
        environment_to_deployment: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentMessage] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosting_service", b"hosting_service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "environment_to_deployment", b"environment_to_deployment", "hosting_service", b"hosting_service", "model_id", b"model_id"]) -> None: ...

global___DeployModelRequest = DeployModelRequest

class DeployModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToDeploymentResultEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentDeploymentResultMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentDeploymentResultMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEPLOYMENT_NAMED_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_DEPLOYMENT_RESULT_FIELD_NUMBER: builtins.int
    deployment_named_id: builtins.str
    """ID of deployment - in order to check up on status changes"""
    status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType
    """Status of deployment"""
    info: builtins.str
    """Additional info on the deployment"""
    @property
    def environment_to_deployment_result(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentResultMessage]:
        """Environment ids to their deployment result mapping"""
    def __init__(
        self,
        *,
        deployment_named_id: builtins.str = ...,
        status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType = ...,
        info: builtins.str = ...,
        environment_to_deployment_result: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentResultMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_named_id", b"deployment_named_id", "environment_to_deployment_result", b"environment_to_deployment_result", "info", b"info", "status", b"status"]) -> None: ...

global___DeployModelResponse = DeployModelResponse

class UndeployModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToUndeploymentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentUndeploymentMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentUndeploymentMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    HOSTING_SERVICE_TYPE_FIELD_NUMBER: builtins.int
    TRAFFIC_CONFIG_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_UNDEPLOYMENT_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model named ID to undeploy"""
    branch_id: builtins.str
    """Branch ID to undeploy from"""
    hosting_service_type: qwak.deployment.deployment_pb2.DeploymentHostingServiceType.ValueType
    """The Hosting service to undeploy from"""
    @property
    def traffic_config(self) -> qwak.deployment.deployment_pb2.TrafficConfig:
        """Traffic Config"""
    variation_name: builtins.str
    """Deployment variation name"""
    @property
    def environment_to_undeployment(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentUndeploymentMessage]:
        """Environment ids to their undeployment request mapping"""
    model_uuid: builtins.str
    """Model UUID to undeploy"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        hosting_service_type: qwak.deployment.deployment_pb2.DeploymentHostingServiceType.ValueType = ...,
        traffic_config: qwak.deployment.deployment_pb2.TrafficConfig | None = ...,
        variation_name: builtins.str = ...,
        environment_to_undeployment: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentUndeploymentMessage] | None = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["traffic_config", b"traffic_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "environment_to_undeployment", b"environment_to_undeployment", "hosting_service_type", b"hosting_service_type", "model_id", b"model_id", "model_uuid", b"model_uuid", "traffic_config", b"traffic_config", "variation_name", b"variation_name"]) -> None: ...

global___UndeployModelRequest = UndeployModelRequest

class UndeployModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToUndeploymentResultEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentUndeploymentResultMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentUndeploymentResultMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_UNDEPLOYMENT_RESULT_FIELD_NUMBER: builtins.int
    status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType
    """Status of un-deployment"""
    info: builtins.str
    @property
    def environment_to_undeployment_result(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentUndeploymentResultMessage]:
        """Environment ids to their undeployment result mapping"""
    def __init__(
        self,
        *,
        status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType = ...,
        info: builtins.str = ...,
        environment_to_undeployment_result: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentUndeploymentResultMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_to_undeployment_result", b"environment_to_undeployment_result", "info", b"info", "status", b"status"]) -> None: ...

global___UndeployModelResponse = UndeployModelResponse

class GetDeploymentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    """The deployment id to get"""
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id"]) -> None: ...

global___GetDeploymentRequest = GetDeploymentRequest

class GetDeploymentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_DETAILS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_PHASES_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def deployments_details(self) -> qwak.deployment.deployment_pb2.DeploymentDetails:
        """The Deployment details"""
    @property
    def deployment_phases_details(self) -> qwak.deployment.deployment_pb2.DeploymentPhasesDetails:
        """The deployment phase"""
    def __init__(
        self,
        *,
        deployments_details: qwak.deployment.deployment_pb2.DeploymentDetails | None = ...,
        deployment_phases_details: qwak.deployment.deployment_pb2.DeploymentPhasesDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_phases_details", b"deployment_phases_details", "deployments_details", b"deployments_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_phases_details", b"deployment_phases_details", "deployments_details", b"deployments_details"]) -> None: ...

global___GetDeploymentResponse = GetDeploymentResponse

class GetDeploymentStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_NAMED_ID_FIELD_NUMBER: builtins.int
    HOSTING_SERVICE_TYPE_FIELD_NUMBER: builtins.int
    deployment_named_id: builtins.str
    """ID of deployment to check up on"""
    hosting_service_type: qwak.deployment.deployment_pb2.DeploymentHostingServiceType.ValueType
    """The Hosting service to get status from"""
    def __init__(
        self,
        *,
        deployment_named_id: builtins.str = ...,
        hosting_service_type: qwak.deployment.deployment_pb2.DeploymentHostingServiceType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_named_id", b"deployment_named_id", "hosting_service_type", b"hosting_service_type"]) -> None: ...

global___GetDeploymentStatusRequest = GetDeploymentStatusRequest

class GetDeploymentStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType
    """Current status of deployment"""
    def __init__(
        self,
        *,
        status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___GetDeploymentStatusResponse = GetDeploymentStatusResponse

class UpdateDeploymentRuntimeSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToRuntimeDeploymentSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_SETTINGS_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_RUNTIME_DEPLOYMENT_SETTINGS_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model named ID, which will be used as a routing key for the model"""
    branch_id: builtins.str
    """Branch ID which the model was deployed under"""
    @property
    def deployment_settings(self) -> qwak.deployment.deployment_pb2.RuntimeDeploymentSettings:
        """The new  deployment settings"""
    variation_name: builtins.str
    """Variation name"""
    @property
    def environment_to_runtime_deployment_settings(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsMessage]:
        """Environment ids to their update runtime deployment request mapping"""
    model_uuid: builtins.str
    """Model UUID."""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        deployment_settings: qwak.deployment.deployment_pb2.RuntimeDeploymentSettings | None = ...,
        variation_name: builtins.str = ...,
        environment_to_runtime_deployment_settings: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsMessage] | None = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_settings", b"deployment_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "deployment_settings", b"deployment_settings", "environment_to_runtime_deployment_settings", b"environment_to_runtime_deployment_settings", "model_id", b"model_id", "model_uuid", b"model_uuid", "variation_name", b"variation_name"]) -> None: ...

global___UpdateDeploymentRuntimeSettingsRequest = UpdateDeploymentRuntimeSettingsRequest

class UpdateDeploymentRuntimeSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToRuntimeDeploymentSettingsResponseEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsResultMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsResultMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENVIRONMENT_TO_RUNTIME_DEPLOYMENT_SETTINGS_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def environment_to_runtime_deployment_settings_response(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsResultMessage]:
        """Environment ids to their update runtime deployment response mapping"""
    def __init__(
        self,
        *,
        environment_to_runtime_deployment_settings_response: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentRuntimeDeploymentSettingsResultMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_to_runtime_deployment_settings_response", b"environment_to_runtime_deployment_settings_response"]) -> None: ...

global___UpdateDeploymentRuntimeSettingsResponse = UpdateDeploymentRuntimeSettingsResponse

class GetDeploymentDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID"""
    branch_id: builtins.str
    """The branch ID"""
    model_uuid: builtins.str
    """The model UUID"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...

global___GetDeploymentDetailsRequest = GetDeploymentDetailsRequest

class GetDeploymentDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToDeploymentDetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentDeploymentDetailsMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentDeploymentDetailsMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class BuildToEnvironmentDeploymentStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.BuildDeploymentEnvironmentStatus: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.BuildDeploymentEnvironmentStatus | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CURRENT_DEPLOYMENT_DETAILS_FIELD_NUMBER: builtins.int
    LAST_DEPLOYMENT_BRIEF_FIELD_NUMBER: builtins.int
    CURRENT_DEPLOYMENTS_DETAILS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_DEPLOYMENT_DETAILS_FIELD_NUMBER: builtins.int
    MULTI_ENV_SUPPORT_FIELD_NUMBER: builtins.int
    BUILD_TO_ENVIRONMENT_DEPLOYMENT_STATUS_FIELD_NUMBER: builtins.int
    @property
    def current_deployment_details(self) -> qwak.deployment.deployment_pb2.DeploymentDetails:
        """The current active deployment details."""
    @property
    def last_deployment_brief(self) -> qwak.deployment.deployment_pb2.DeploymentBrief:
        """The last finalize deployment."""
    @property
    def current_deployments_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.DeploymentDetails]:
        """The current active deployments details"""
    @property
    def environment_to_deployment_details(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentDetailsMessage]:
        """Environment ids to their deployment details mapping"""
    multi_env_support: builtins.bool
    """Flag whether multi env is supported (only for the transition phase)"""
    @property
    def build_to_environment_deployment_status(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.BuildDeploymentEnvironmentStatus]:
        """Last deployment status by build"""
    def __init__(
        self,
        *,
        current_deployment_details: qwak.deployment.deployment_pb2.DeploymentDetails | None = ...,
        last_deployment_brief: qwak.deployment.deployment_pb2.DeploymentBrief | None = ...,
        current_deployments_details: collections.abc.Iterable[qwak.deployment.deployment_pb2.DeploymentDetails] | None = ...,
        environment_to_deployment_details: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentDetailsMessage] | None = ...,
        multi_env_support: builtins.bool = ...,
        build_to_environment_deployment_status: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.BuildDeploymentEnvironmentStatus] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current_deployment_details", b"current_deployment_details", "last_deployment_brief", b"last_deployment_brief"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_to_environment_deployment_status", b"build_to_environment_deployment_status", "current_deployment_details", b"current_deployment_details", "current_deployments_details", b"current_deployments_details", "environment_to_deployment_details", b"environment_to_deployment_details", "last_deployment_brief", b"last_deployment_brief", "multi_env_support", b"multi_env_support"]) -> None: ...

global___GetDeploymentDetailsResponse = GetDeploymentDetailsResponse

class GetDeploymentHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    branch_id: builtins.str
    """The branch ID"""
    model_uuid: builtins.str
    """The Model UUID"""
    build_id: builtins.str
    """The Build ID"""
    def __init__(
        self,
        *,
        branch_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "filter_by", b"filter_by", "model_uuid", b"model_uuid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "filter_by", b"filter_by", "model_uuid", b"model_uuid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["filter_by", b"filter_by"]) -> typing_extensions.Literal["model_uuid", "build_id"] | None: ...

global___GetDeploymentHistoryRequest = GetDeploymentHistoryRequest

class GetDeploymentHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToDeploymentHistoryEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentDeploymentHistoryMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentDeploymentHistoryMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_DEPLOYMENT_HISTORY_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.DeploymentBrief]:
        """All finalized deployments for specific branch"""
    @property
    def environment_to_deployment_history(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentHistoryMessage]:
        """Environment ids to their deployment history mapping"""
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[qwak.deployment.deployment_pb2.DeploymentBrief] | None = ...,
        environment_to_deployment_history: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentDeploymentHistoryMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments", "environment_to_deployment_history", b"environment_to_deployment_history"]) -> None: ...

global___GetDeploymentHistoryResponse = GetDeploymentHistoryResponse

class PushEnvironmentDeploymentStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STATE_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    @property
    def deployment_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.KubernetesModelDeploymentState]: ...
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        deployment_state: collections.abc.Iterable[qwak.deployment.deployment_pb2.KubernetesModelDeploymentState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_state", b"deployment_state", "environment_id", b"environment_id"]) -> None: ...

global___PushEnvironmentDeploymentStateRequest = PushEnvironmentDeploymentStateRequest

class PushEnvironmentDeploymentStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PushEnvironmentDeploymentStateResponse = PushEnvironmentDeploymentStateResponse

class ApplyModelTrafficRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    VARIATIONS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model Id"""
    @property
    def variations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.Variation]:
        """The variations config"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Environment ids to apply traffic on"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        variations: collections.abc.Iterable[qwak.deployment.deployment_pb2.Variation] | None = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_ids", b"environment_ids", "model_id", b"model_id", "variations", b"variations"]) -> None: ...

global___ApplyModelTrafficRequest = ApplyModelTrafficRequest

class ApplyModelTrafficResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToApplyModelTrafficResponseEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentApplyModelTrafficResponse: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentApplyModelTrafficResponse | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENVIRONMENT_TO_APPLY_MODEL_TRAFFIC_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def environment_to_apply_model_traffic_response(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentApplyModelTrafficResponse]:
        """Environment ids to their apply traffic response mapping"""
    def __init__(
        self,
        *,
        environment_to_apply_model_traffic_response: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentApplyModelTrafficResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_to_apply_model_traffic_response", b"environment_to_apply_model_traffic_response"]) -> None: ...

global___ApplyModelTrafficResponse = ApplyModelTrafficResponse

class GetModelTrafficRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model Id"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id"]) -> None: ...

global___GetModelTrafficRequest = GetModelTrafficRequest

class GetModelTrafficResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToModelTrafficEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.EnvironmentTrafficMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.EnvironmentTrafficMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    VARIATIONS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TO_MODEL_TRAFFIC_FIELD_NUMBER: builtins.int
    MULTI_ENV_SUPPORT_FIELD_NUMBER: builtins.int
    @property
    def variations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.Variation]:
        """The variations config"""
    @property
    def environment_to_model_traffic(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.EnvironmentTrafficMessage]:
        """Environment ids to their traffic"""
    multi_env_support: builtins.bool
    """Flag whether multi env is supported (only for the transition phase)"""
    def __init__(
        self,
        *,
        variations: collections.abc.Iterable[qwak.deployment.deployment_pb2.Variation] | None = ...,
        environment_to_model_traffic: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.EnvironmentTrafficMessage] | None = ...,
        multi_env_support: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_to_model_traffic", b"environment_to_model_traffic", "multi_env_support", b"multi_env_support", "variations", b"variations"]) -> None: ...

global___GetModelTrafficResponse = GetModelTrafficResponse

class IsBuildDeployedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_UUIDS_FIELD_NUMBER: builtins.int
    @property
    def build_uuids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_uuids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_uuids", b"build_uuids"]) -> None: ...

global___IsBuildDeployedRequest = IsBuildDeployedRequest

class IsBuildDeployedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.BuildDeploymentStatus]: ...
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[qwak.deployment.deployment_pb2.BuildDeploymentStatus] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments"]) -> None: ...

global___IsBuildDeployedResponse = IsBuildDeployedResponse

class IsBuildInUseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_UUIDS_FIELD_NUMBER: builtins.int
    @property
    def build_uuids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_uuids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_uuids", b"build_uuids"]) -> None: ...

global___IsBuildInUseRequest = IsBuildInUseRequest

class IsBuildInUseResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.BuildDeploymentStatus]: ...
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[qwak.deployment.deployment_pb2.BuildDeploymentStatus] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments"]) -> None: ...

global___IsBuildInUseResponse = IsBuildInUseResponse

class CancelDeploymentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_IDS_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    @property
    def deployment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The deployment ids"""
    model_id: builtins.str
    """The model to cancel deployments from"""
    def __init__(
        self,
        *,
        deployment_ids: collections.abc.Iterable[builtins.str] | None = ...,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_ids", b"deployment_ids", "model_id", b"model_id"]) -> None: ...

global___CancelDeploymentsRequest = CancelDeploymentsRequest

class CancelDeploymentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CancelRequestStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.deployment.deployment_pb2.CancelDeploymentRequestStatus: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.deployment.deployment_pb2.CancelDeploymentRequestStatus | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CANCEL_REQUEST_STATUS_FIELD_NUMBER: builtins.int
    @property
    def cancel_request_status(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.deployment.deployment_pb2.CancelDeploymentRequestStatus]:
        """The status of the cancel request"""
    def __init__(
        self,
        *,
        cancel_request_status: collections.abc.Mapping[builtins.str, qwak.deployment.deployment_pb2.CancelDeploymentRequestStatus] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel_request_status", b"cancel_request_status"]) -> None: ...

global___CancelDeploymentsResponse = CancelDeploymentsResponse

class ListLiveModelsDeploymentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_uuid: builtins.str
    def __init__(
        self,
        *,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_uuid", b"model_uuid"]) -> None: ...

global___ListLiveModelsDeploymentsRequest = ListLiveModelsDeploymentsRequest

class ListLiveModelsDeploymentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.DeploymentDetails]: ...
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[qwak.deployment.deployment_pb2.DeploymentDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments"]) -> None: ...

global___ListLiveModelsDeploymentsResponse = ListLiveModelsDeploymentsResponse



from dataclasses import dataclass, field
from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    BatchSource as ProtoBatchSource,
    ParquetSource as ProtoParquetSource,
)
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from qwak.feature_store.data_sources import AnonymousS3Configuration
from qwak.feature_store.data_sources.batch._batch import BaseBatchSource
from qwak.feature_store.data_sources.batch.filesystem.base_config import (
    FileSystemConfiguration,
)
from qwak.feature_store.data_sources.batch.filesystem.utils import (
    get_fs_config_from_proto,
)


@dataclass
class ParquetSource(BaseBatchSource):
    path: str
    filesystem_configuration: FileSystemConfiguration = field(
        default_factory=lambda: AnonymousS3Configuration()
    )

    @classmethod
    def _from_proto(cls, proto):
        parquet: ProtoParquetSource = proto.parquetSource
        fs_conf = get_fs_config_from_proto(parquet.filesystem_configuration)

        return cls(
            name=proto.name,
            date_created_column=proto.date_created_column,
            description=proto.description,
            path=parquet.path,
            filesystem_configuration=fs_conf,
        )

    def _to_proto(self, artifact_url: Optional[str] = None):
        fs_conf = None
        if self.filesystem_configuration:
            fs_conf = self.filesystem_configuration._to_proto()

        return ProtoDataSourceSpec(
            batch_source=ProtoBatchSource(
                name=self.name,
                description=self.description,
                date_created_column=self.date_created_column,
                parquetSource=ProtoParquetSource(
                    path=self.path, filesystem_configuration=fs_conf
                ),
            )
        )
